==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nodes/node/group/buckets/bucket/action/action/NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nodes.node.group.buckets.bucket.action.action;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.dec.nsh.ttl.grouping.NxDecNshTtl;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder
 * @see Builder
 *
 */
public class NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder implements Builder<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase> {

    private NxDecNshTtl _nxDecNshTtl;


    Map<Class<? extends Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>>, Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>> augmentation = Collections.emptyMap();

    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder() {
    }
    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping arg) {
        this._nxDecNshTtl = arg.getNxDecNshTtl();
    }

    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder(NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>>, Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>> aug =((AugmentationHolder<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxDecNshTtl = base.getNxDecNshTtl();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping) {
            this._nxDecNshTtl = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping)arg).getNxDecNshTtl();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping]");
    }

    public NxDecNshTtl getNxDecNshTtl() {
        return _nxDecNshTtl;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder setNxDecNshTtl(final NxDecNshTtl value) {
        this._nxDecNshTtl = value;
        return this;
    }
    
    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>> augmentationType, Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase build() {
        return new NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseImpl(this);
    }

    private static final class NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseImpl
        extends AbstractAugmentable<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>
        implements NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase {
    
        private final NxDecNshTtl _nxDecNshTtl;
    
        NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseImpl(NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder base) {
            super(base.augmentation);
            this._nxDecNshTtl = base.getNxDecNshTtl();
        }
    
        @Override
        public Class<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase> getImplementedInterface() {
            return NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase.class;
        }
    
        @Override
        public NxDecNshTtl getNxDecNshTtl() {
            return _nxDecNshTtl;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxDecNshTtl);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase other = (NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase)obj;
            if (!Objects.equals(_nxDecNshTtl, other.getNxDecNshTtl())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseImpl otherImpl = (NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>>, Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase");
            CodeHelpers.appendValue(helper, "_nxDecNshTtl", _nxDecNshTtl);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.9.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nodes/node/group/buckets/bucket/action/action/NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nodes.node.group.buckets.bucket.action.action;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.dec.nsh.ttl.grouping.NxDecNshTtl;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder} instances.
 *
 * @see NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder
 *
 */
public class NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder implements Builder<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase> {

    private NxDecNshTtl _nxDecNshTtl;


    Map<Class<? extends Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>>, Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>> augmentation = Collections.emptyMap();

    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder() {
    }
    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping arg) {
        this._nxDecNshTtl = arg.getNxDecNshTtl();
    }

    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder(NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>>, Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>> aug =((AugmentationHolder<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._nxDecNshTtl = base.getNxDecNshTtl();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping) {
            this._nxDecNshTtl = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping)arg).getNxDecNshTtl();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping]");
    }

    public NxDecNshTtl getNxDecNshTtl() {
        return _nxDecNshTtl;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder setNxDecNshTtl(final NxDecNshTtl value) {
        this._nxDecNshTtl = value;
        return this;
    }
    
    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>> augmentationType, Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase build() {
        return new NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseImpl(this);
    }

    private static final class NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseImpl
        extends AbstractAugmentable<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>
        implements NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase {
    
        private final NxDecNshTtl _nxDecNshTtl;
    
        NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseImpl(NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseBuilder base) {
            super(base.augmentation);
            this._nxDecNshTtl = base.getNxDecNshTtl();
        }
    
        @Override
        public NxDecNshTtl getNxDecNshTtl() {
            return _nxDecNshTtl;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxDecNshTtl);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase other = (NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase)obj;
            if (!Objects.equals(_nxDecNshTtl, other.getNxDecNshTtl())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseImpl otherImpl = (NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCaseImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>>, Augmentation<NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionDecNshTtlNodesNodeGroupBucketsBucketActionsCase");
            CodeHelpers.appendValue(helper, "_nxDecNshTtl", _nxDecNshTtl);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
